# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/inventory/purchase/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/inventory/purchase/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Inventory\\Purchase\\": "packages/inventory/purchase/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Inventory\Purchase\Providers\PurchaseServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Purchase'  => Inventory\Purchase\Facades\Purchase::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Inventory\\PurchaseTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Inventory\Purchase\Providers\PurchaseServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Inventory\Purchase\Providers\PurchaseServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Inventory\Purchase\Providers\PurchaseServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/purchase/{modulename}

**User**

    http://path-to-route-folder/user/purchase/{modulename}

**Public**

    http://path-to-route-folder/purchases


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/purchase/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/purchase/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/purchase/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/purchase/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/purchase/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/purchase/{modulename}/{slug}
    METHOD: GET