<?php

namespace Inventory\Purchase\Providers;

use Illuminate\Support\ServiceProvider;

class PurchaseServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'purchase');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'purchase');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPurchase();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPurchase()
    {
        $this->app->bind('purchase', function($app) {
            return new Purchase($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Purchase', 'Lavalite\Purchase\Facades\Purchase');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('inventory.purchase', function ($app) {
            return $this->app->make('Inventory\Purchase\Purchase');
        });

        // Bind Order to repository
        $this->app->bind(
            'Inventory\Purchase\Interfaces\OrderRepositoryInterface',
            \Inventory\Purchase\Repositories\Eloquent\OrderRepository::class
        );        // Bind Item to repository
        $this->app->bind(
            'Inventory\Purchase\Interfaces\ItemRepositoryInterface',
            \Inventory\Purchase\Repositories\Eloquent\ItemRepository::class
        );

        $this->app->register(\Inventory\Purchase\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Inventory\Purchase\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and purchase's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'inventory.purchase'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePurchase::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['inventory.purchase'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('inventory/purchase.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/purchase')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/purchase')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
