<?php

namespace Inventory\Purchase\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Inventory\Purchase\Models\Purchase;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Inventory\Purchase\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/purchase/order/*')) {
            Route::bind('order', function ($order) {
                $orderrepo = $this->app->make('Inventory\Purchase\Interfaces\OrderRepositoryInterface');
                return $orderrepo->findorNew($order);
            });
        }
        if (Request::is('*/purchase/item/*')) {
            Route::bind('item', function ($item) {
                $itemrepo = $this->app->make('Inventory\Purchase\Interfaces\ItemRepositoryInterface');
                return $itemrepo->findorNew($item);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
